@@ -5,22 +5,24 @@
 
 #define PTY	/* Enable vt100 support parallel with nfsd */
 
-#define MTAB_PATH	"/etc/mnttab"
+#define MTAB_PATH	"/etc/mtab"
 #ifdef linux
-# define MTAB_TMP	"/etc/mnttab~"
+# define MTAB_TMP	"/etc/mtab~"
 #else
-# define MTAB_TMP	"/etc/mnttab.p3nfsd"
+# define MTAB_TMP	"/etc/mtab.p3nfsd"
 #endif
 
-#define DDEV		"/dev/term/a"
+#define DDEV		"/dev/ttyS0"
 /*
  * hpux10		/dev/tty0p0
  * hpux			/dev/tty00
  * linux		/dev/ttyS0
  * sun && __svr4__ 	/dev/term/a
+ * NeXT 		/dev/ttyfa
  * sun  		/dev/ttya
  * _IBMR2		/dev/tty0
  * __sgi		/dev/ttyf1
+ * FreeBSD 3.1		/dev/cuaa1
  */
 
 #ifdef _IBMR2
@@ -36,6 +38,11 @@ ERROR: p3nfsd is not yet ported to this system
 # define DDIR "/psion.stand/mnt"
 #endif
 
+#ifndef PSIONHOSTNAME
+# define PSIONHOSTNAME "localhost"
+#endif
+
+
 #define DSPEED 19200
 
 /* See CHANGES for comment */
