@@ -3,10 +3,15 @@
 #include "mp.h"
 #include "cnv.h"
 
-#ifdef __SVR4
+#if defined(__SVR4) || defined(__GLIBC__) || defined(__FreeBSD__)
 #include <string.h>
 #include <stdlib.h>
 #endif
+#ifdef __NeXT__
+#include <string.h>
+#include <objc/hashtable.h>
+#define strdup NXCopyStringBuffer
+#endif
 #define HASHSIZE 99
 
 static int nextinode = 6;
