@@ -1,3 +1,4 @@
+#include <OSdefs.h>
 #include <stdio.h>
 #include <signal.h>
 #include <fcntl.h>
@@ -9,10 +10,18 @@
 #if defined (__SVR4) || defined(__sgi)
 #include <stdlib.h>		/* getenv */
 #include <string.h>		/* strcmp */
-#include <unistd.h>		/* getuid */
 #endif
+#include <unistd.h>		/* getuid */
 
 #include <dirent.h>
+#if defined(__NeXT__)
+#include <sys/dir.h>
+#include <unistd.h>
+#define DIRENT struct direct
+#else
+#define DIRENT struct dirent
+#endif
+
 
 extern void nfs_program_2();
 
@@ -48,7 +57,7 @@ int usec;
 }
 #endif /* hpux */
 
-void
+int
 main(ac, av)
   int ac;
   char *av[];
@@ -59,7 +68,7 @@ main(ac, av)
   p_inode *rp;
   nfs_fh root_fh;
   DIR *dirp;
-  struct dirent *diep;
+  DIRENT *diep;
   int i;
 
 
@@ -109,7 +118,7 @@ main(ac, av)
       else if (!strcmp(av[1], "-series5"))
         {
 	  series5 = 1;
-	  if(speed == 0) speed = 38400;
+	  if(speed == 0) speed = 56700;
 	}
       else if (!strcmp(av[1], "-speed"))
         {
@@ -131,7 +140,7 @@ main(ac, av)
 	  printf("              [-oldnfsc] [-series5] [-]\n");
 #endif
 	  printf("Defaults: -dir %s -user %s -tty %s -speed %d\n", dir, user, dev, DSPEED);
-	  exit(1);
+	  return 1;
 	}
       ac--;av++;
     }
@@ -141,18 +150,18 @@ main(ac, av)
       if(!(pw = getpwnam(user)))
 	{
 	  fprintf(stderr, "User %s not found.\n", user);
-	  exit(1);
+	  return 1;
 	}
     }
   else if(!(pw = getpwuid(getuid())))
     {
       fprintf(stderr, "You don't exist, go away!\n");
-      exit(1);
+      return 1;
     }
   if (getuid() && pw->pw_uid != getuid())
     {
       fprintf(stderr, "%s? You must be kidding...\n", user);
-      exit(1);
+      return 1;
     }
   root_fattr.uid = pw->pw_uid;
   root_fattr.gid = pw->pw_gid;
@@ -179,7 +188,7 @@ main(ac, av)
   if(!(dirp = opendir(dir)))
     {
       perror(dir);
-      exit(1);
+      return 1;
     }
   i = 0;
   while((diep = readdir(dirp)) != 0)
@@ -189,7 +198,7 @@ main(ac, av)
   if(i)
     {
       fprintf(stderr, "Sorry, directory %s is not empty, exiting.\n", dir);
-      exit(1);
+      return 1;
     }
 
 
@@ -205,5 +214,5 @@ main(ac, av)
   root_fattr.ctime.seconds = tv.tv_sec;
 
   mount_and_run(dir, dev, nfs_program_2, &root_fh);
-  exit(0);
+  return 0;
 }
