@@ -1,37 +1,65 @@
+#if defined(__SVR4) || defined(__sgi) || defined(linux)
+#  include <stdlib.h>
+#  include <unistd.h>
+#  include <string.h>	/* strdup */
+#  ifndef linux
+     extern int inet_addr(char *);
+#  endif
+#  define PORTMAP	/* I need svcudp_create in rpc/svc_soc.h, sol 2.4 */
+#endif
+
+#include <OSdefs.h>
 #include <stdio.h>
 #include <signal.h>
 #include <sys/stat.h>
 #include <sys/wait.h>
 
-#if defined(__SVR4) || defined(__sgi)
-#include <stdlib.h>
-#include <unistd.h>
-#include <string.h>		/* strdup */
-extern int inet_addr(char *);
-#define PORTMAP		/* I need svcudp_create in rpc/svc_soc.h, sol 2.4 */
-#endif
 
 #ifdef __sgi
 #include <bstring.h>
 #endif
 
-#ifdef __NetBSD__
+#if defined(__NetBSD__) || defined(__FreeBSD__)
 #include <sys/param.h>        /* Needs NGROUPS for mount.h */
 #define umount(dir) unmount(dir, 1)
 #endif
 
+#if defined(__NeXT__)
+#include <libc.h>
+#include <unistd.h>
+#include <nfs/nfs_mount.h>
+#define umount(dir) unmount(dir)
+#endif
 
-#define PSIONHOSTNAME "localhost"
 #include "config.h"
 
 static char nfshost[128];
 
 #define NFSCLIENT
+#ifdef __FreeBSD__
+#define NFS
+#endif /* __FreeBSD__ */
 #include <sys/mount.h>
 
+#ifdef __FreeBSD__
+# include <sys/socket.h>
+# include <netinet/in.h>
+# include <arpa/inet.h>
+# include <rpc/rpc.h>
+# include <nfs/rpcv2.h>
+# if __FreeBSD_version >= 300001
+#  include <nfs/nfs.h>
+# endif
+#endif /* __FreeBSD__ */
+
+#include <rpc/rpc.h>
+#include "nfs_prot.h"
+
 #ifdef linux
-# include <linux/fs.h>		/* struct nfs_sever for linux/nfs_fs.h */
-# include <linux/nfs_fs.h>	/* struct nfs_mount_data */
+# ifndef __GLIBC__
+#   include <linux/fs.h>	/* struct nfs_mount_data */
+# endif
+# include <linux/nfs_mount.h>	/* struct nfs_mount_data */
 # include <arpa/inet.h>		/* inet_addr() */
 #endif
 #ifdef _IBMR2
@@ -40,8 +68,6 @@ static char nfshost[128];
 # include <sys/vmount.h>
 #endif
 
-#include <rpc/rpc.h>
-#include "nfs_prot.h"
 
 #ifndef DONT_UPDATE_MTAB
 #if defined(sun) && defined(__SVR4)
@@ -67,7 +93,6 @@ extern int _rpc_dtablesize();
 
 #include <sys/socket.h>
 #include <netdb.h>
-#include <rpc/rpc.h>
 
 #include "mp.h"
 
@@ -108,13 +133,17 @@ hup_handler SIGARG
 static void
 doexit()
 {
+#ifndef DONT_UPDATE_MTAB
   FILE *fpin, *fpout;
 #if defined(sun) && defined(__SVR4)
   struct mntent entr;
 #else
   struct mntent *ent;
 #endif
+#endif
+#ifndef __FreeBSD__
   struct stat statb;
+#endif
 
   exiting--;
 
@@ -209,6 +238,11 @@ mount_and_run(dir, dev, proc, root_fh)
   int isalive = 0, ret, dtbsize;
   SVCXPRT *nfsxprt;
   int bufsiz = 0xc000;	                    /* room for a few biods */
+#ifdef __NeXT__
+  union wait waitstat;
+#else
+  int waitstat;
+#endif
 #ifdef linux
   struct nfs_mount_data nfs_mount_data;
   int mount_flags;
@@ -217,6 +251,10 @@ mount_and_run(dir, dev, proc, root_fh)
 #else
   struct nfs_args nfs_args;
 #endif
+#ifdef __FreeBSD__
+  int mount_flags;
+#endif
+
 
 
   sprintf(nfshost, "localhost:%s", dev);
@@ -254,6 +292,10 @@ mount_and_run(dir, dev, proc, root_fh)
     {
       perror("svc_register"); exit(1);
     }
+  if (debug)
+    printf("created svc PROG=%d, VER=%d port=%d\n",
+    	NFS_PROGRAM, NFS_VERSION, port);
+    
 
 /*** Second part: mount the directory */
 #ifdef linux
@@ -356,7 +398,8 @@ mount_and_run(dir, dev, proc, root_fh)
   }
 #endif /* solaris */
 
-#if (defined(sun) && !defined(__SVR4))  || defined(hpux) || defined(__sgi)
+/* BSD Derived systems */
+#if (defined(sun) && !defined(__SVR4))  || defined(hpux) || defined(__sgi) || defined(__NeXT__)
   nfs_args.addr     = &sain;
   nfs_args.fh       = (void *)root_fh;
   nfs_args.wsize    = PBUFSIZE;
@@ -371,6 +414,31 @@ mount_and_run(dir, dev, proc, root_fh)
                    NFSMNT_RETRANS | NFSMNT_TIMEO | NFSMNT_WSIZE | NFSMNT_RSIZE;
 #endif
 
+#ifdef __FreeBSD__
+# if __FreeBSD_version >= 300001
+  nfs_args.version  = NFS_ARGSVERSION;
+# endif
+  nfs_args.addr     = (struct sockaddr *)&sain;
+  nfs_args.addrlen  = sizeof(sain);
+  nfs_args.sotype   = SOCK_DGRAM;
+  nfs_args.fh       = (void *)root_fh;
+  nfs_args.fhsize   = sizeof(*root_fh);
+  nfs_args.wsize    = PBUFSIZE;
+  nfs_args.rsize    = PBUFSIZE;
+  nfs_args.retrans = 10;
+  /* 1 minute timeout - see below */
+  nfs_args.timeo = 600;
+  nfs_args.hostname = PSIONHOSTNAME;
+  nfs_args.flags    =
+       NFSMNT_INT |
+       NFSMNT_SOFT |
+       NFSMNT_RETRANS |
+       NFSMNT_TIMEO |
+       NFSMNT_WSIZE |
+       NFSMNT_RSIZE;
+  mount_flags =       MNT_NOSUID | MNT_NODEV | MNT_NOEXEC | MNT_NOATIME;
+#endif
+
 #ifdef __NetBSD__
   nfs_args.addrlen = sizeof(sain) ;
   nfs_args.sotype = SOCK_DGRAM ;
@@ -417,7 +485,7 @@ mount_and_run(dir, dev, proc, root_fh)
 #if defined(__sgi) || (defined(sun) && defined(__SVR4))
         if(mount("", dir, MS_DATA, "nfs", &nfs_args, sizeof(nfs_args)))
 #endif
-#ifdef __NetBSD__
+#if defined(__NetBSD__) || defined(__NeXT__)
 	if(mount(MOUNT_NFS, dir, 0, (caddr_t)&nfs_args))
 #endif
 #ifdef hpux
@@ -432,6 +500,15 @@ mount_and_run(dir, dev, proc, root_fh)
 #ifdef _IBMR2
 	if(aix3_mount("psion:loc", dir, 0, MOUNT_TYPE_NFS, &nfs_args, "p3nfsd"))
 #endif
+
+#ifdef __FreeBSD__
+# if __FreeBSD_version >= 300001
+      if(mount("nfs", dir, mount_flags, &nfs_args))
+# else
+      if(mount(MOUNT_NFS, dir, mount_flags, &nfs_args))
+# endif
+#endif
+
 	  {
 	    extern int errno;
 
@@ -475,7 +552,7 @@ mount_and_run(dir, dev, proc, root_fh)
 #endif /* !DONT_UPDATE_MTAB */
 	  }
 	if(!background)
-	  while(wait(&ret) != pid)
+	  while(wait(&waitstat) != pid)
 	    ;
 	exit(0);
     }
