@@ -1,6 +1,7 @@
+#include "OSdefs.h"
 #include <stdio.h>
 #include <ctype.h>
-#ifdef __SVR4
+#if defined(__SVR4) || defined(__GLIBC__)
 #include <stdlib.h>
 #include <unistd.h>
 #include <string.h>
@@ -160,12 +161,17 @@ query_devices()
       dp = (struct device *)malloc(sizeof(struct device));
       *pp = dp;
       dp->next = 0;
-      for(p = sp = cp2iso(namebuf); *p; p++)
-        if (isupper(*p))	/* norm@city.ac.uk, SunOS 4.0.2 */
-	  *p = tolower(*p);
-	/* Convert ISO8859-1 */
-	else if(*(unsigned char *)p >= 0xc0 && *(unsigned char *)p <= 0xde) 
-	  *p += 0x20;
+      if(series5)
+        sp = namebuf;
+      else
+	{
+	  for(p = sp = cp2iso(namebuf); *p; p++)
+	    if (isupper(*p))	/* norm@city.ac.uk, SunOS 4.0.2 */
+	      *p = tolower(*p);
+	    /* Convert ISO8859-1 */
+	    else if(*(unsigned char *)p >= 0xc0 && *(unsigned char *)p <= 0xde) 
+	      *p += 0x20;
+	}
       dp->name = (char *)strdup((char *)sp);
 
       if(getcount(dp->attrib, 14))
@@ -455,12 +461,17 @@ nfsproc_readdir_2(ra)
 	      return &res;
 	    }
 	  if(!*buf) break;
-	  for(sp = p = cp2iso(buf); *p; p++)
-	    /* Convert ISO8859-1 */
-	    if(*(unsigned char *)p >= 0xc0 && *(unsigned char *)p <= 0xde)
-	      *p += 0x20;
-            else if (isupper(*p))	/* norm@city.ac.uk, SunOS 4.0.2 */
-	      *p = tolower(*p);
+	  if(series5)
+	    sp = buf;
+	  else
+	    {
+	      for(sp = p = cp2iso(buf); *p; p++)
+		/* Convert ISO8859-1 */
+		if(*(unsigned char *)p >= 0xc0 && *(unsigned char *)p <= 0xde)
+		  *p += 0x20;
+		else if (isupper(*p))	/* norm@city.ac.uk, SunOS 4.0.2 */
+		  *p = tolower(*p);
+	    }
 
 	  bp = filname(sp);
 	  addentry(ra, &cp, &searchinode,
